==> tailwind-react-ui-0.6.0.tgz: package/README.md <==
# Tailwind React Component Library

[![CircleCI](https://circleci.com/gh/emortlock/tailwind-react.svg?style=svg)](https://circleci.com/gh/emortlock/tailwind-react) [![Greenkeeper badge](https://badges.greenkeeper.io/emortlock/tailwind-react.svg)](https://greenkeeper.io/)

---

**NB:** As the 0.#.# version number suggests this is still very much work in progress, so semantic versioning will not be followed until a v1 release is solidified. Expect breaking changes to occur on minor version jumps.

---

Tailwind React provides ready built components that make use of the [Tailwind CSS](https://tailwindcss.com/) framework.

If you're unfamiliar with the concepts behind Tailwind you can get an overview at https://tailwindcss.com/docs/what-is-tailwind:

> Creating a framework for building custom UIs means you can't provide abstractions at the usual level of buttons, forms, cards, navbars, etc.
> Instead, Tailwind provides highly composable, low-level utility classes that make it easy to build complex user interfaces.

Tailwind React leverages these utility classes to provide base level components that are common across various projects, whilst still offering the ability to customise the output to match your project's style.

## Useful Links

- [GitHub repository](https://github.com/emortlock/tailwind-react)

- [Documentation](https://emortlock.github.io/tailwind-react/#documentation)

- [Component demos](https://emortlock.github.io/tailwind-react/#component-demos)

- [Component APIs](https://emortlock.github.io/tailwind-react/#component-apis)

==> tailwind-react-ui-0.6.1.tgz: package/README.md <==
# Tailwind React UI

[![CircleCI](https://circleci.com/gh/emortlock/tailwind-react-ui.svg?style=svg)](https://circleci.com/gh/emortlock/tailwind-react-ui) [![Greenkeeper badge](https://badges.greenkeeper.io/emortlock/tailwind-react-ui.svg)](https://greenkeeper.io/)

---

**NB:** As the 0.#.# version number suggests this is still very much work in progress, so semantic versioning will not be followed until a v1 release is solidified. Expect breaking changes to occur on minor version jumps.

---

Tailwind React UI provides ready built components that make use of [Tailwind CSS](https://tailwindcss.com/) utility framework.

If you're unfamiliar with the concepts behind Tailwind you can get an overview at https://tailwindcss.com/docs/what-is-tailwind:

> Creating a framework for building custom UIs means you can't provide abstractions at the usual level of buttons, forms, cards, navbars, etc.
> Instead, Tailwind provides highly composable, low-level utility classes that make it easy to build complex user interfaces.

Tailwind React UI leverages these utility classes to provide base level components that are common across various projects, whilst still offering the ability to customise the output to match your project's style.

## Useful Links

- [GitHub repository](https://github.com/emortlock/tailwind-react)

- [Documentation](https://emortlock.github.io/tailwind-react/#documentation)

- [Component demos](https://emortlock.github.io/tailwind-react/#component-demos)

- [Component APIs](https://emortlock.github.io/tailwind-react/#component-apis)
